@@ -30,7 +30,7 @@ simulate_hmm <- function(
     states = if (!hierarchy) 2 else c(2, 2), 
     sdds = if (!hierarchy) "normal" else c("normal", "normal"), 
     horizon = if (!hierarchy) 100 else c(100, 30),
-    period = if (hierarchy && is.na(horizon[2])) "m" else NA, 
+    period = NA, 
     true_parameters = fHMM_parameters(
       controls = controls, hierarchy = hierarchy, states = states, sdds = sdds
     ), 
